@@ -5,7 +5,7 @@ from typing import Any, Union, Type, Dict
 import threading
 
 import pyobs.interfaces
-from pyobs.events import Event, LogEvent, ModuleOpenedEvent, ModuleClosedEvent
+from pyobs.events import Event, LogEvent, ModuleClosedEvent
 from .proxy import Proxy
 from .sharedvariablecache import SharedVariableCache
 from .commlogging import CommLoggingHandler
@@ -16,6 +16,7 @@ log = logging.getLogger(__name__)
 
 class Comm:
     """Base class for all Comm modules in pyobs."""
+    __module__ = 'pyobs.comm'
 
     def __init__(self, cache_proxies: bool = True, *args, **kwargs):
         """Creates a comm module."""
@@ -39,10 +40,12 @@ class Comm:
 
     @property
     def module(self):
+        """The module that this Comm object is attached to."""
         return self._module
 
     @module.setter
     def module(self, module):
+        """The module that this Comm object is attached to."""
         # if we have a _set_module method, call it
         if hasattr(self, '_set_module'):
             self._set_module(module)
@@ -210,7 +213,7 @@ class Comm:
             List of supported interfaces.
 
         Raises:
-            IndexError, if client cannot be found.
+            IndexError: If client cannot be found.
         """
         raise NotImplementedError
 
@@ -262,33 +265,6 @@ class Comm:
                 log.error('Could not find interface "%s" for client.', interface_name)
         return interface_classes
 
-    def add_command_handler(self, command: str, handler):
-        """Add a command handler.
-
-        Args:
-            command (str): Name of command to handle.
-            handler: Method that handles the command
-        """
-        raise NotImplementedError
-
-    def del_command_handler(self, command: str, handler):
-        """Delete a command handler.
-
-        Args:
-            command: Name of command to handle.
-            handler: Method that handles the command
-        """
-        raise NotImplementedError
-
-    def send_text_message(self, client: str, msg: str):
-        """Send a text message to another client.
-
-        Args:
-            client: ID of client to send message to.
-            msg: Message to send.
-        """
-        raise NotImplementedError
-
     def execute(self, client: str, method: str, *args) -> Any:
         """Execute a given method on a remote client.
 
