@@ -136,7 +136,9 @@ class RPC(object):
 
         except Exception as e:
             # something else went wrong
-            # log.exception('Error during call to %s: %s', pmethod, str(e))
+            log.warning('Error during call to %s: %s', pmethod, str(e), exc_info=True)
+
+            # send response
             fault = dict()
             fault['code'] = 500
             fault['string'] = str(e)
@@ -155,6 +157,7 @@ class RPC(object):
             args = xml2py(iq['rpc_query']['method_response']['params'])
         except ValueError:
             log.error('Could not parse method response: %s', iq)
+            return
 
         # get future
         pid = iq['id']
