@@ -1,3 +1,8 @@
+"""
+TODO: write doc
+"""
+__title__ = 'Events'
+
 from .badweather import BadWeatherEvent
 from .exposurestatuschanged import ExposureStatusChangedEvent
 from .event import Event
