@@ -4,6 +4,9 @@ from .event import Event
 
 
 class GoodWeatherEvent(Event):
+    """Event to be sent on good weather."""
+    __module__ = 'pyobs.events'
+
     def __init__(self, eta: Time = None):
         """Initializes a new good weather event.
 
