@@ -2,6 +2,8 @@ from .event import Event
 
 
 class ModuleClosedEvent(Event):
+    """Event to be sent when a module has closed."""
+    __module__ = 'pyobs.events'
     local = True
 
     def __init__(self):
