@@ -2,6 +2,9 @@ from .event import Event
 
 
 class TelescopeMovingEvent(Event):
+    """Event to be sent when the telescope has started moving."""
+    __module__ = 'pyobs.events'
+
     def __init__(self, ra: float = None, dec: float = None, alt: float = None, az: float = None):
         """Initializes a new telescope moving event.
 
