@@ -4,7 +4,8 @@ from .interface import Interface
 
 
 class IAltAz(Interface):
-    """Base interface for everything that can move to Alt/Az coordinates."""
+    """The module can move to Alt/Az coordinates, usually combined with :class:`~pyobs.interfaces.ITelescope`."""
+    __module__ = 'pyobs.interfaces'
 
     def move_altaz(self, alt: float, az: float, *args, **kwargs):
         """Moves to given coordinates.
