@@ -4,7 +4,9 @@ from .interface import Interface
 
 
 class IAltAzOffsets(Interface):
-    """Telescopes on an altaz mount should also implement this interface."""
+    """The module supports Alt/Az offsets, usually combined with :class:`~pyobs.interfaces.ITelescope` and
+    :class:`~pyobs.interfaces.IAltAz`."""
+    __module__ = 'pyobs.interfaces'
 
     def set_altaz_offsets(self, dalt: float, daz: float, *args, **kwargs):
         """Move an Alt/Az offset.
