@@ -4,12 +4,15 @@ from .IAbortable import IAbortable
 
 
 class IAutoFocus(IAbortable):
+    """The module can perform an auto-focus."""
+    __module__ = 'pyobs.interfaces'
+
     def auto_focus(self, count: int, step: float, exposure_time: int, *args, **kwargs) -> Tuple[float, float]:
         """Perform an auto-focus series.
 
         This method performs an auto-focus series with "count" images on each side of the initial guess and the given
         step size. With count=3, step=1 and guess=10, this takes images at the following focus values:
-            7, 8, 9, 10, 11, 12, 13
+        7, 8, 9, 10, 11, 12, 13
 
         Args:
             count: Number of images to take on each side of the initial guess. Should be an odd number.
