@@ -2,6 +2,9 @@ from .IStoppable import IStoppable
 
 
 class IAutoGuiding(IStoppable):
+    """The module can perform auto-guiding."""
+    __module__ = 'pyobs.interfaces'
+
     def set_exposure_time(self, exposure_time: float, *args, **kwargs):
         """Set the exposure time for the auto-guider.
 
