@@ -1,9 +1,12 @@
-from typing import Tuple
+from typing import Tuple, List
 
 from .interface import Interface
 
 
 class ICameraBinning(Interface):
+    """The camera supports binning, to be used together with :class:`~pyobs.interfaces.ICamera`."""
+    __module__ = 'pyobs.interfaces'
+
     def set_binning(self, x: int, y: int, *args, **kwargs):
         """Set the camera binning.
 
@@ -24,5 +27,13 @@ class ICameraBinning(Interface):
         """
         raise NotImplementedError
 
+    def list_binnings(self, *args, **kwargs) -> List[Tuple[int, int]]:
+        """List available binnings.
+
+        Returns:
+            List of available binnings as (x, y) tuples.
+        """
+        raise NotImplementedError
+
 
 __all__ = ['ICameraBinning']
