@@ -4,6 +4,9 @@ from .interface import Interface
 
 
 class ICameraWindow(Interface):
+    """The camera supports windows, to be used together with :class:`~pyobs.interfaces.ICamera`."""
+    __module__ = 'pyobs.interfaces'
+
     def get_full_frame(self, *args, **kwargs) -> Tuple[int, int, int, int]:
         """Returns full size of CCD.
 
