@@ -2,6 +2,9 @@ from .interface import Interface
 
 
 class IFocusModel(Interface):
+    """The module provides a model for the telescope focus, e.g. based on temperatures."""
+    __module__ = 'pyobs.interfaces'
+
     def get_optimal_focus(self, *args, **kwargs) -> float:
         """Returns the optimal focus."""
         raise NotImplementedError
