@@ -2,11 +2,8 @@ from .IMotion import IMotion
 
 
 class IFocuser(IMotion):
-    """Generic focussing device with states corresponding to IMotionDevice.MotionState.
-
-    Other interfaces to be implemented:
-        (none)
-    """
+    """The module is a focusing device."""
+    __module__ = 'pyobs.interfaces'
 
     def set_focus(self, focus: float, *args, **kwargs):
         """Sets new focus.
