@@ -4,7 +4,9 @@ from .interface import Interface
 
 
 class ILatLon(Interface):
-    """Base interface for everything that can move to Lat/Lon coordinates."""
+    """The module can move to general Lat/Lon coordinates, which have to be defined by the module itself.
+    Usually combined with :class:`~pyobs.interfaces.ITelescope`."""
+    __module__ = 'pyobs.interfaces'
 
     def move_latlon(self, lat: float, lon: float, *args, **kwargs):
         """Moves to given coordinates.
