@@ -2,7 +2,8 @@ from .interface import Interface
 
 
 class IReady(Interface):
-    """Interface for all devices that can be "not ready" for science and need to be initialized in some way."""
+    """The module can be in a "not ready" state for science and need to be initialized in some way."""
+    __module__ = 'pyobs.interfaces'
 
     def is_ready(self, *args, **kwargs) -> bool:
         """Returns the device is "ready", whatever that means for the specific device.
