@@ -2,6 +2,9 @@ from .IMotion import IMotion
 
 
 class IRotation(IMotion):
+    """The module controls a device that can rotate."""
+    __module__ = 'pyobs.interfaces'
+
     def set_rotation(self, angle, *args, **kwargs):
         """ Sets the rotation angle to the given value in degrees. """
         raise NotImplementedError
