@@ -3,15 +3,18 @@ import time
 from threading import Event
 from typing import Union, List
 
-from pyobs import Module
+from pyobs.modules import Module
 from pyobs.interfaces import IMotion
+from pyobs.utils.enums import MotionStatus
 
 log = logging.getLogger(__name__)
 
 
 class WaitForMotionMixin:
     """Mixin for a device that should wait for the motion status of another device."""
-    def __init__(self, wait_for_modules: List[str] = None, wait_for_states: List[Union[IMotion.Status, str]] = None,
+    __module__ = 'pyobs.mixins'
+
+    def __init__(self, wait_for_modules: List[str] = None, wait_for_states: List[Union[MotionStatus, str]] = None,
                  wait_for_timeout: float = 0, *args, **kwargs):
         """Initializes the mixin.
 
@@ -23,7 +26,7 @@ class WaitForMotionMixin:
 
         # store
         self.__wait_for_modules = wait_for_modules if wait_for_modules is not None else []
-        self.__wait_for_states = [s if isinstance(s, IMotion.Status) else IMotion.Status(s)
+        self.__wait_for_states = [s if isinstance(s, MotionStatus) else MotionStatus(s)
                                   for s in wait_for_states] if wait_for_states is not None else []
         self.__wait_for_timeout = wait_for_timeout
 
@@ -34,7 +37,7 @@ class WaitForMotionMixin:
             event: Abort event.
 
         Raises:
-            TimeoutError if wait timed out.
+            TimeoutError: If wait timed out.
         """
 
         # no device?
