@@ -3,7 +3,7 @@ import threading
 import typing
 
 from pyobs.interfaces import IRunnable, IFlatField
-from pyobs import Module
+from pyobs.modules import Module
 from pyobs.modules import timeout
 from pyobs.object import get_object
 from pyobs.utils.skyflats.priorities.base import SkyflatPriorities
@@ -16,6 +16,7 @@ log = logging.getLogger(__name__)
 
 class FlatFieldScheduler(Module, IRunnable):
     """Run the flat-field scheduler."""
+    __module__ = 'pyobs.modules.flatfield'
 
     def __init__(self, flatfield: typing.Union[str, IFlatField], functions: typing.Dict[str, str],
                  priorities: typing.Union[dict, SkyflatPriorities], min_exptime: float = 0.5, max_exptime: float = 5,
