@@ -2,27 +2,30 @@ from typing import Tuple, Dict, List
 
 import numpy as np
 import logging
-from pyobs import get_object
+from pyobs.object import get_object
 
-from pyobs.utils.photometry import Photometry
+from pyobs.images.processors.detection import SourceDetection
 from .base import FocusSeries
 from pyobs.utils.curvefit import fit_hyperbola
-from pyobs.utils.images import Image
+from pyobs.images import Image
 
 
 log = logging.getLogger(__name__)
 
 
 class PhotometryFocusSeries(FocusSeries):
-    def __init__(self, photometry: Photometry, radius_column: str = 'radius', *args, **kwargs):
+    """Focus series based on source detection."""
+    __module__ = 'pyobs.utils.focusseries'
+
+    def __init__(self, source_detection: SourceDetection, radius_column: str = 'radius', *args, **kwargs):
         """Initialize a new projection focus series.
 
         Args:
-            photometry: Photometry to use for estimating PSF sizes
+            source_detection: Photometry to use for estimating PSF sizes
         """
 
         # stuff
-        self._photometry: Photometry = get_object(photometry, Photometry)
+        self._source_detection: SourceDetection = get_object(source_detection, SourceDetection)
         self._radius_col = radius_column
         self._data: List[Dict[str, float]] = []
 
@@ -38,7 +41,7 @@ class PhotometryFocusSeries(FocusSeries):
         """
 
         # do photometry
-        sources = self._photometry.find_stars(image)
+        sources = self._source_detection(image)
         sources = sources[sources['ellipticity'] < 0.1]
         sources = sources[sources['peak'] > 1000]
         sources = sources[sources['radius'] > 0]
