@@ -2,7 +2,7 @@ import typing
 from astropy.time import TimeDelta
 import astropy.units as u
 
-from pyobs import get_object
+from pyobs.object import get_object
 from pyobs.interfaces import ICamera
 from pyobs.utils.archive import Archive
 from pyobs.utils.time import Time
@@ -11,6 +11,9 @@ from ...enums import ImageType
 
 
 class ArchiveSkyflatPriorities(SkyflatPriorities):
+    """Calculate flat priorities from an archive."""
+    __module__ = 'pyobs.utils.skyflats.priorities'
+
     def __init__(self, archive: typing.Union[dict, Archive], site: str, instrument: str, filter_names: list,
                  binnings: list, *args, **kwargs):
         SkyflatPriorities.__init__(self)
