@@ -2,6 +2,9 @@ from .base import SkyflatPriorities
 
 
 class ConstSkyflatPriorities(SkyflatPriorities):
+    """Constant flat priorities."""
+    __module__ = 'pyobs.utils.skyflats.priorities'
+
     def __init__(self, priorities: dict, *args, **kwargs):
         SkyflatPriorities.__init__(self)
         self._priorities = priorities
